package com.nto.presentation.screens.profileScreen

import android.content.ContentValues.TAG
import android.util.Log
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.journeyapps.barcodescanner.ScanContract
import com.journeyapps.barcodescanner.ScanOptions
import com.nto.presentation.CustomCaptureActivity
import com.nto.data.utils.Destinations
import com.nto.presentation.R
import com.nto.presentation.composable.DecoratedButton
import com.nto.presentation.composable.cards.VisitCard
import com.nto.presentation.theme.NTOTheme
import com.nto.presentation.theme.TextGray

@Composable
fun ProfileScreen(
    navController: NavController,
    modifier: Modifier = Modifier,
    viewModel: ProfileViewModel = hiltViewModel<ProfileViewModel>(),
) {
    val state = viewModel.state.collectAsState().value

    val scannerLauncher = rememberLauncherForActivityResult(
        contract = ScanContract(),
        onResult = { result -> Log.i(TAG, "scanned code: ${result.contents}") }
    )
    val scanOptions = ScanOptions()
    scanOptions.setPrompt("")
    scanOptions.setBeepEnabled(false)
    scanOptions.setDesiredBarcodeFormats(ScanOptions.QR_CODE)
    scanOptions.setOrientationLocked(false)
    scanOptions.setCaptureActivity(CustomCaptureActivity::class.java)

    LaunchedEffect(Unit) {
        if (state.isUnauthorized) {
            //navController.navigate(Destinations.Login)
        }
    }

    Column(
        modifier = modifier.background(NTOTheme.colors.primaryBackground)
    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(start = 20.dp, end = 20.dp)
        ) {
            Spacer(modifier = Modifier.height(10.dp))
            Column(modifier = Modifier.weight(1f)) {
                Row(
                    modifier = Modifier.fillMaxWidth(),
                    horizontalArrangement = Arrangement.SpaceBetween,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text(
                        stringResource(R.string.title_profile),
                        style = NTOTheme.typography.titleLarge,
                        fontSize = 36.sp,
                        fontWeight = FontWeight.Bold
                    )
                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Box(
                            modifier = Modifier
                                .size(35.dp)
                                .clip(CircleShape)
                                .border(2.dp, NTOTheme.colors.buttonAdmin, shape = CircleShape),
                            contentAlignment = Alignment.Center
                        ) {
                            IconButton(modifier = Modifier.size(25.dp), onClick = {
                                viewModel.admin(navController)
                            }) {
                                Icon(
                                    painter = painterResource(R.drawable.icon_admin),
                                    modifier = Modifier.size(20.dp),
                                    contentDescription = null,
                                    tint = NTOTheme.colors.buttonAdmin
                                )
                            }
                        }
                        Spacer(modifier = Modifier.width(8.dp))
                        Box(
                            modifier = Modifier
                                .size(35.dp)
                                .clip(CircleShape)
                                .border(2.dp, NTOTheme.colors.buttonDisabled, shape = CircleShape),
                            contentAlignment = Alignment.Center
                        ) {
                            IconButton(modifier = Modifier.size(25.dp), onClick = {
                                viewModel.option(navController)
                            }) {
                                Icon(
                                    painter = painterResource(R.drawable.icon_options),
                                    modifier = Modifier.size(20.dp),
                                    contentDescription = null,
                                    tint = NTOTheme.colors.buttonDisabled
                                )
                            }
                        }
                        Spacer(modifier = Modifier.width(14.dp))
                        Box(
                            modifier = Modifier
                                .size(35.dp)
                                .clip(CircleShape)
                                .background(NTOTheme.colors.buttonDisabled),
                            contentAlignment = Alignment.Center
                        ) {
                            IconButton(modifier = Modifier.size(25.dp), onClick = {
                                viewModel.logout(navController)
                            }) {
                                Icon(
                                    painter = painterResource(R.drawable.icon_logout),
                                    modifier = Modifier.size(20.dp),
                                    contentDescription = null,
                                    tint = NTOTheme.colors.primaryBackground
                                )
                            }
                        }
                    }

                }
                Spacer(modifier = Modifier.height(50.dp))
                Row(modifier = Modifier.fillMaxWidth()) {
                    Image(
                        painter = painterResource(R.drawable.logo_placeholder_user),
                        modifier = Modifier
                            .size(100.dp)
                            .clip(
                                CircleShape
                            ),
                        contentDescription = null
                    )
                    Spacer(modifier = Modifier.width(15.dp))
                    Column(
                        modifier = Modifier
                            .fillMaxWidth()
                            .clip(RoundedCornerShape(10.dp))
                            .background(NTOTheme.colors.inputFieldBackground)
                            .padding(10.dp)
                    ) {
                        Text(
                            state.secondName,
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Text(
                            state.firstName,
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Text(
                            state.thirdName,
                            style = NTOTheme.typography.displaySmall,
                            fontWeight = FontWeight.Bold
                        )
                        Spacer(modifier = Modifier.height(10.dp))
                        Text(
                            state.job,
                            style = NTOTheme.typography.placeholder,
                            color = TextGray
                        )
                    }
                }
                Spacer(modifier = Modifier.height(20.dp))
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .height(35.dp)
                        .clip(RoundedCornerShape(10.dp))
                        .background(NTOTheme.colors.inputFieldBackground)
                        .padding(start = 15.dp, end = 15.dp),
                    verticalAlignment = Alignment.CenterVertically,
                    horizontalArrangement = Arrangement.SpaceBetween
                ) {
                    Text(
                        stringResource(R.string.label_last_visit),
                        style = NTOTheme.typography.placeholder,
                        fontSize = 12.sp
                    )
                    Text(
                        state.lastOpen, style = NTOTheme.typography.placeholder, fontSize = 12.sp
                    )
                }
                Spacer(modifier = Modifier.height(20.dp))
                Text(
                    stringResource(R.string.label_visits),
                    style = NTOTheme.typography.displaySmall,
                    fontWeight = FontWeight.Bold
                )
                Spacer(modifier = Modifier.height(10.dp))

                LazyColumn(verticalArrangement = Arrangement.spacedBy(10.dp)) {
                    items(state.visits) { item ->
                        VisitCard(item)
                    }
                }
            }
            DecoratedButton(
                stringResource(R.string.label_scan),
                false,
                modifier = Modifier
                    .padding(bottom = 10.dp)
                    .fillMaxWidth()
                    .height(62.dp)
            ) {
                scannerLauncher.launch(scanOptions)
                viewModel.scan(navController)
            }
        }
    }
}

@Preview
@Composable
private fun ProfileScreenPreview() {
    NTOTheme {
        ProfileScreen(rememberNavController(), Modifier.fillMaxSize())
    }
}